@@ -8,7 +8,7 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 
-__version__ = '0.0.17'
+__version__ = '0.0.19'
 
 import sys
 
@@ -31,6 +31,7 @@ login = wandb_sdk.login
 Settings = wandb_sdk.Settings
 
 from wandb.util import preinit as _preinit
+from wandb.util import lazyloader as _lazyloader
 from wandb.errors.term import termlog, termerror, termwarn
 
 # Move this (keras.__init__ expects it at top level)
@@ -63,6 +64,8 @@ summary = _preinit.PreInitObject("wandb.summary")
 log = _preinit.PreInitCallable("wandb.log")
 join = _preinit.PreInitCallable("wandb.join")
 
+keras = _lazyloader.LazyLoader('wandb.keras', globals(), 'wandb.framework.keras')
+
 __all__ = [
     "__version__",
     "init",
