@@ -1,3 +1,13 @@
+# -*- coding: utf-8 -*-
+"""
+keras init
+"""
+
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import copy
 import operator
 import os
