@@ -141,7 +141,7 @@ class _WandbInit(object):
             return
         self._atexit_cleanup_called = True
 
-        ret = self.backend.interface.send_exit_sync(0, timeout=30)
+        ret = self.backend.interface.send_exit_sync(0, timeout=60)
         logger.info("got exit ret: %s", ret)
 
         self._restore()
@@ -284,22 +284,19 @@ class _WandbInit(object):
 
         backend._hack_set_run(run)
 
-        run_config = run.config._as_dict()
-        logger.info("runconfig: %s", run_config)
-        r = dict(run_id=run.run_id, config=run_config, project=s.project)
         if s.mode == 'online':
-            ret = backend.interface.send_run_sync(r, timeout=30)
+            ret = backend.interface.send_run_sync(run, timeout=30)
             # TODO: fail on error, check return type
             run._set_run_obj(ret.run)
         elif s.mode in ('offline', 'dryrun'):
-            backend.interface.send_run(r)
+            backend.interface.send_run(run)
         elif s.mode in ('async', 'run'):
             try:
-                err = backend.interface.send_run_sync(r, timeout=10)
+                err = backend.interface.send_run_sync(run, timeout=10)
             except Backend.Timeout:
                 pass
             # TODO: on network error, do async run save
-            backend.interface.send_run(r)
+            backend.interface.send_run(run)
 
         self.run = run
         self.backend = backend
