@@ -13,7 +13,7 @@ import six
 
 logger = logging.getLogger("wandb")
 
-source = ("org", "team", "project", "sysdir", "dir", "env", "setup",
+source = ("org", "entity", "project", "sysdir", "dir", "env", "setup",
           "settings", "args")
 
 Field = collections.namedtuple('TypedField', ['type', 'choices'])
@@ -49,7 +49,6 @@ defaults = dict(
 # env mapping?
 env_prefix = "WANDB_"
 env_settings = dict(
-    team=None,
     entity=None,
     project=None,
     base_url=None,
@@ -58,8 +57,13 @@ env_settings = dict(
     job_type=None,
     problem=None,
     console=None,
+    run_name="WANDB_NAME",
+    run_notes="WANDB_NOTES",
+    run_tags="WANDB_TAGS",
 )
 
+env_convert = dict(run_tags=lambda s: s.split(','), )
+
 
 def _build_inverse_map(prefix, d):
     inv_map = dict()
@@ -88,8 +92,7 @@ class Settings(six.with_metaclass(CantTouchThis, object)):
     """Settings Constructor
 
     Args:
-        entity: alias for team.
-        team: personal user or team to use for Run.
+        entity: personal user or team to use for Run.
         project: project name for the Run.
 
     Raises:
@@ -98,25 +101,24 @@ class Settings(six.with_metaclass(CantTouchThis, object)):
     """
 
     # pylint: disable=no-member
-
-    team: Optional[str]
     entity: Optional[str]
 
     def __init__(  # pylint: disable=unused-argument
         self,
-        team: Optional[str] = None,
-        entity: Optional[str] = None,
-        project: Optional[str] = None,
         base_url: Optional[str] = None,
         api_key: Optional[str] = None,
         anonymous=None,
 
         # how do we annotate that: dryrun==offline?
         mode: Optional[str] = 'online',
-        group=None,
-        job_type=None,
-        run_name=None,
-        run_id=None,
+        entity: str = None,
+        project: str = None,
+        group: str = None,
+        job_type: str = None,
+        run_id: str = None,
+        run_name: str = None,
+        run_notes: str = None,
+        run_tags=None,
 
         # compatibility / error handling
         compat_version=None,  # set to "0.8" for safer defaults for older users
@@ -193,6 +195,9 @@ class Settings(six.with_metaclass(CantTouchThis, object)):
                     continue
                 setting_key = inv_map.get(k)
                 if setting_key:
+                    conv = env_convert.get(setting_key, None)
+                    if conv:
+                        v = conv(v)
                     env_dict[setting_key] = v
                 else:
                     l.info("Unhandled environment var: {}".format(k))
@@ -311,7 +316,7 @@ class Settings(six.with_metaclass(CantTouchThis, object)):
 
     def apply_init(self, args):
         # strip out items where value is None
-        param_map = dict(name='run_name', id='run_id')
+        param_map = dict(name='run_name', id='run_id', tags='run_tags')
         args = {
             param_map.get(k, k): v
             for k, v in six.iteritems(args) if v is not None
